import picocli.CommandLine;
import picocli.CommandLine.Option;

public class Main implements Runnable {

    @Option(names = {"-x", "--xkcd"}, description = "Will generate an xkcd-style password (See xkcd 936)")
    private boolean xkcd = false;

    @Option(names = {"-s", "--simple"}, description = "Will generate a password of specified length without special characters")
    private boolean simple = false;

    @Option(names = {"-l", "--length"}, description = "Will generate a regular password with the provided amount of characters (or words for XKCD passwords). Defaults to 32.")
    private int length = 32;

    @Option(names = {"-h", "--help"}, usageHelp = true, description = "Displays this help message and exits.")
    private boolean help;

    public static void main(String[] args) {
        int exitCode = new CommandLine(new Main()).execute(args);
        System.exit(exitCode);
    }

    @Override
    public void run() {
        final Passgen passgen = new Passgen();
        if (xkcd && simple) {
            System.out.println("Error: Only use one of xkcd (-x), simple (-s) or regular (-r) at once.");
            System.exit(2);
        }
        if (xkcd) {
            System.out.println(passgen.generate_xkcd_password(length));
            System.exit(0);
        }
        else if (simple) {
            System.out.println(passgen.generate_simple_password(length));
            System.exit(0);
        }
        else {
            System.out.println(passgen.generate_regular_password(length));
            System.exit(0);
        }
    }
}
